package com.spring.series.jdbc.dao.impl;

import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.jdbc.core.BeanPropertyRowMapper;
import org.springframework.jdbc.core.simple.ParameterizedBeanPropertyRowMapper;
import org.springframework.jdbc.core.simple.SimpleJdbcTemplate;
import org.springframework.stereotype.Repository;

import com.spring.series.jdbc.dao.PlayerDAO;
import com.spring.series.jdbc.model.Player;

@Repository("playerDAO")
public class PlayerDAOImpl implements PlayerDAO {

	@Autowired
	private SimpleJdbcTemplate simpleJdbcTemplate;

	public SimpleJdbcTemplate getSimpleJdbcTemplate() {
		return simpleJdbcTemplate;
	}

	/**
	 * create or inserts the new player information into the database using simpleJdbcTemplate
	 */
	@SuppressWarnings("deprecation")
	public String createOrSaveNewPLayer(Player player) {

		String sql = "INSERT INTO PLAYER(NAME, AGE, MATCHES) VALUES(?, ?, ?)";
		int returnValue = getSimpleJdbcTemplate().update(
				sql, 
				player.getName(), 
				player.getAge(), 
				player.getMatches());
		if(1 == returnValue)
			return "Player creation is SUCCESS";
		else
			return "Player creation is FAILURE";
	}

	/**
	 * This method retrieves a player from database using jdbcTemplate based on the PLAYER_ID supplied in the formal arguments
	 */
	@SuppressWarnings("deprecation")
	public Player getPlayer(int playerId) {

		String sql = "SELECT PLAYER_ID, NAME, AGE, MATCHES FROM PLAYER WHERE PLAYER_ID = ?";
		Player player = getSimpleJdbcTemplate().queryForObject(
				sql, 
				ParameterizedBeanPropertyRowMapper.newInstance(Player.class), 
				playerId);
		return player;
	}

	/**
	 * This method updates the player information in the database using simpleJdbcTemplate
	 */
	@SuppressWarnings("deprecation")
	public String updatePlayerInfo(Player player) {

		String sql = "UPDATE PLAYER SET NAME = ?, AGE = ?, MATCHES = ? WHERE PLAYER_ID = ?";
		int returnValue = getSimpleJdbcTemplate().update(
				sql, 
				player.getName(), 
				player.getAge(), 
				player.getMatches(), 
				player.getPlayerId());
		if(1 == returnValue)
			return "Player updation is SUCCESS";
		else
			return "Player updation is FAILURE";
	}

	/**
	 * This method deletes the player information from the database using simpleJdbcTemplate
	 */
	@SuppressWarnings("deprecation")
	public String deletePlayerInfo(String player_id) {

		String sql = "DELETE FROM PLAYER WHERE PLAYER_ID = ?";
		int returnValue = getSimpleJdbcTemplate().update(
				sql, 
				player_id);
		if(1 == returnValue)
			return "Player deletion is SUCCESS";
		else
			return "Player deletion is FAILURE";
	}

	/**
	 * Retrieves all players from the database using simpleJdbcTemplate
	 */
	@SuppressWarnings({ "rawtypes", "unchecked", "deprecation" })
	public List<Player> getAllPlayer() {

		// local variables
		String sql = "SELECT PLAYER_ID, NAME, AGE, MATCHES FROM PLAYER";
		List<Player> lstPlayers  = getSimpleJdbcTemplate().query(
				sql, 
				new BeanPropertyRowMapper(Player.class));
		return lstPlayers;
	}
}